============================
``psyclone.gen_kernel_stub``
============================

.. automodule:: psyclone.gen_kernel_stub

   .. contents::
      :local:

.. currentmodule:: psyclone.gen_kernel_stub
